@@ -19,9 +19,9 @@
 
 #include <string.h>
 #include <gtk/gtk.h>
+#include <gdk/gdkx.h>
 #include "gailwidget.h"
 #include "gailnotebookpage.h"
-#include "gailcanvaswidget.h"
 #include "gail-private-macros.h"
 
 extern GtkWidget *focus_widget;
@@ -570,7 +570,9 @@ gail_widget_get_index_in_parent (AtkObject *accessible)
   GtkWidget *parent_widget;
   gint index;
   GList *children;
+  GType type;
 
+  type = g_type_from_name ("GailCanvasWidget");
   widget = GTK_ACCESSIBLE (accessible)->widget;
 
   if (widget == NULL)
@@ -586,7 +588,7 @@ gail_widget_get_index_in_parent (AtkObject *accessible)
       parent = accessible->accessible_parent;
 
       if (GAIL_IS_NOTEBOOK_PAGE (parent) ||
-          GAIL_IS_CANVAS_WIDGET (parent))
+          G_TYPE_CHECK_INSTANCE_TYPE ((parent), type))
         return 0;
       else
         {
@@ -766,7 +768,7 @@ gail_widget_grab_focus (AtkComponent   *component)
       gtk_widget_grab_focus (widget);
       toplevel = gtk_widget_get_toplevel (widget);
       if (GTK_WIDGET_TOPLEVEL (toplevel))
-        gtk_window_present (GTK_WINDOW (toplevel)); 
+        gtk_window_present_with_time (GTK_WINDOW (toplevel), gdk_x11_get_server_time (widget->window));
       return TRUE;
     }
   else
